@@ -7,12 +7,14 @@ from typing import Callable
 from typing import Dict
 from typing import Iterable
 from typing import Mapping
+from typing import Optional
 from typing import Union
 
 import numpy as np
 import tensorflow as tf
 from sklearn.model_selection import ParameterGrid
 from sklearn.model_selection import ParameterSampler
+from tensorflow.keras.callbacks import TensorBoard
 from tensorflow.keras.models import Model
 
 from tensorcross._types import ResultsDict
@@ -27,8 +29,8 @@ class BaseSearchCV(metaclass=ABCMeta):
     with cross validation.
 
     Args:
-        model_fn (Callable[..., tf.keras.models.Model]): Function that
-            builds and compiles a tf.keras.models.Model object.
+        model_fn (Callable[..., Model]): Function that
+            builds and compiles a Model object.
         n_folds (int): How many folds. Defaults to 3.
         verbose (int): Whether to show information in terminal.
             Defaults to 0.
@@ -67,22 +69,25 @@ class BaseSearchCV(metaclass=ABCMeta):
             parameter_obj (ParameterGrid | ParameterSampler): Object to iterate
                 over, to generate hyperparameter combinations.
             kwargs (Any): Keyword arguments for the fit method of the
-                tf.keras.models.Model or tf.keras.models.Sequential model.
+                Model or tf.keras.models.Sequential model.
         """
+        if len(dataset) == 0:
+            raise ValueError("Data Set is empty!")
+
         maximize = True
-        tensorboard_callback = None
+        tensorboard_callback: Optional[TensorBoard] = None
         tensorboard_log_dir = ""
 
         for param, value in kwargs.items():
             if param == "callbacks":
                 for callback in value:
-                    if isinstance(callback, tf.keras.callbacks.TensorBoard):
+                    if isinstance(callback, TensorBoard):
                         tensorboard_callback = callback
 
         if tensorboard_callback:
             tensorboard_log_dir = tensorboard_callback.log_dir
 
-        split_fraction = 1 / self.n_folds
+        split_fraction = 1.0 / self.n_folds
 
         tf_log_level = logger.level
         logger.setLevel(logging.ERROR)  # Issue 30: Ignore warnings for training
@@ -104,6 +109,8 @@ class BaseSearchCV(metaclass=ABCMeta):
                 train_dataset, val_dataset = dataset_split(
                     dataset=dataset, split_fraction=split_fraction, fold=fold
                 )
+                if len(val_dataset) == 0:
+                    raise ValueError("Val Set is empty!")
 
                 if tensorboard_callback:
                     if not os.path.exists(tensorboard_log_dir):
@@ -128,7 +135,7 @@ class BaseSearchCV(metaclass=ABCMeta):
 
         logger.setLevel(tf_log_level)  # Issue 30
 
-        mean_val_scores = np.mean(self.results_["val_scores"], axis=0)
+        mean_val_scores = np.mean(self.results_["val_scores"], axis=1)
         if maximize:
             best_run_idx = np.argmax(mean_val_scores)
         else:
@@ -218,8 +225,8 @@ class GridSearchCV(BaseSearchCV):
         mae score.
 
         Args:
-            model_fn (Callable[..., tf.keras.models.Model]): Function that
-                builds and compiles a tf.keras.models.Model object.
+            model_fn (Callable[..., Model]): Function that
+                builds and compiles a Model object.
             param_grid (Mapping[str, Iterable]): Dict of str, iterable
             hyperparameter, where the str is the parameter name of the.
             n_folds (int): How many folds. Defaults to 3.
@@ -238,7 +245,7 @@ class GridSearchCV(BaseSearchCV):
         Args:
             dataset (tf.data.Dataset): tf.data.Dataset object for the training.
             kwargs (Any): Keyword arguments for the fit method of the
-                tf.keras.models.Model or tf.keras.models.Sequential model.
+                Model or tf.keras.models.Sequential model.
         """
         super()._run_search(
             dataset=dataset, parameter_obj=self.param_grid, **kwargs
@@ -284,8 +291,8 @@ class RandomSearchCV(BaseSearchCV):
         mae score.
 
         Args:
-            model_fn (Callable[..., tf.keras.models.Model]): Function that
-                builds and compiles a tf.keras.models.Model object.
+            model_fn (Callable[..., Model]): Function that
+                builds and compiles a Model object.
             param_distributions (Dict[str, Callable]): Dict of str, callable
                 pairs, where the str is the parameter name of the.
             n_iter (int): Number of random models. Defaults to 10.
@@ -309,7 +316,7 @@ class RandomSearchCV(BaseSearchCV):
         Args:
             dataset (tf.data.Dataset): tf.data.Dataset object for the training.
             kwargs (Any): Keyword arguments for the fit method of the
-                tf.keras.models.Model or tf.keras.models.Sequential model.
+                Model or tf.keras.models.Sequential model.
         """
         super()._run_search(
             dataset=dataset, parameter_obj=self.random_sampler, **kwargs
